import React, { useEffect, useState } from "react";
import { Row, Col, Divider, Affix } from "antd";
import { client } from "./gitlab";
import classNames from "classnames";
import "./GitlabIssues.css";

interface User {
  id: number;
  username: string;
}

const users: User[] = [
  { id: 12, username: "marten" },
  { id: 11, username: "henk" },
  { id: 7, username: "jornvandebeek" },
  { id: 8, username: "arnold" },
];
const colWidth = 24 / users.length;

export const GitlabIssues: React.FunctionComponent = () => {
  return (
    <div>
      <Affix>
        <Row>
          {users.map((user) => (
            <Col span={colWidth}>{user.username}</Col>
          ))}
        </Row>
      </Affix>
      <Divider>
        <h2>MRs Ready</h2>
      </Divider>

      <Row>
        {users.map((user) => (
          <Col span={colWidth}>
            <UserMergeRequests user={user} />
          </Col>
        ))}
      </Row>

      <Divider>
        <h2>Issues Assigned</h2>
      </Divider>

      <Row>
        {users.map((user) => (
          <Col span={colWidth}>
            <UserIssues user={user} />
          </Col>
        ))}
      </Row>
    </div>
  );
};

const UserMergeRequests: React.FunctionComponent<{ user: User }> = ({
  user,
}) => {
  const [issues, setIssues] = useState<any>([]);

  useEffect(() => {
    const fetchResults = async () => {
      const result = await client.MergeRequests.all({
        groupId: 6,
        state: "opened",
        wip: "no",
        authorId: user.id,
        scope: "all",
        maxPages: 2,
      });
      setIssues(result);
    };
    fetchResults();
  }, []);

  return (
    <div>
      <ul>
        {issues.map((issue: any) => (
          <li
            className={classNames({
              needsWork: !issue.blocking_discussions_resolved,
            })}
          >
            <a href={issue.web_url}>{issue.title}</a>
          </li>
        ))}
      </ul>
    </div>
  );
};

const UserIssues: React.FunctionComponent<{ user: User }> = ({ user }) => {
  const [issues, setIssues] = useState<any>([]);

  useEffect(() => {
    const fetchResults = async () => {
      const result = await client.Issues.all({
        assigneeId: user.id,
        scope: "all",
        state: "opened",
      });
      console.log(result);
      setIssues(result);
    };
    fetchResults();
  }, []);

  return (
    <div>
      <ul>
        {issues.map((issue: any) => (
          <li>
            <a href={issue.web_url}>{issue.title}</a>
          </li>
        ))}
      </ul>
    </div>
  );
};
